class Newsito():
    def __init__(self, message=None):
        self.message = message
        if self.message is None:
            print("Don't you want to say anything?")
        else:
            print(self.message)



# Change the content according to your package.

# It is very important to update this file every time there is a new version release in Pypi,
# since the imported classes could be used otherwise an error will appear.
# from <<directory.filename.py>> import <<classname>>
from newpackage.newpackage import Newpackage
from newpackage.seconpackage import Newsito
from newpackage.thirdpackage import Newnewsito

# To avoid having to update the setup.py file on each version release, we can declare here some
# important data such as who last modified the package, their email to contact us and what version
# they are on, in the same way. mode add new descriptions on how to use and execute its functions
__author__  = 'D.Mendez'            # <---- Last developer who modified the package
__email__   = 'danielmen@gmail.com' # <---- His email
__version__ = '0.1.0'               # <---- Version

# module level doc-string
__doc__ = """
newpackage
================

Description
-----------
newpackage is a Python package created for demonstration purposes.
This information will show up when using the help function.

-------
Example to use the Newpackage class
>>> # Import library
>>> from newpackage import Newpackage
>>> # Initialize
>>> model = Newpackage(message='Hello World')
>>> # Run the model
>>> model.show()
-------
Example to use the Newsito class
>>> # Import library
>>> from seconpackage import Newsito
>>> # Initialize
>>> Newsito('Hello there')
>>> Newsito()
-------
Example to use the Newnewsito class
>>> # Import library
>>> from thirdpackage import Newnewsito
>>> # Initialize
>>> Newnewsito()

"""


"""This is the newpackage.py script."""

import logging

class Newpackage():
    """Newpackage package class."""

    def __init__(self, name=None):
        """Initialize with user-defined parameters."""
        self.name = name

    def use_logger(self):
        logging.warning(f"Youre logged {self.name}")

    def show(self):
        """Run the show function."""
        if self.name is None:
            print('Hello dude i dont know your name')
        else:
            print(f'Hello {self.name} youre cool')

        # Return
        return None



# Change the content according to your package.
import setuptools
import re
import os

# Extract the version from the init file.
DATAFILE = "newpackage/__init__.py"
getversion = re.search(
    r"^__version__ = ['\"]([^'\"]*)['\"]", open(DATAFILE, "rt").read(), re.M)
if getversion:
    new_version = getversion.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (DATAFILE,))

# Configurations
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    install_requires=[
        'matplotlib',
        'numpy',
        'pandas'
    ],
    python_requires='>=3',
    name='newpackagewebforce',
    version=new_version,
    author="D.Mendez",
    author_email="pablomen1131@gmail.com",
    description="Python package for my newpackagewebforce.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/danielmen-mx/newpackagewebforce",
    download_url='https://github.com/danielmen-mx/newpackagewebforce/archive/'+new_version+'.tar.gz',
    packages=setuptools.find_packages(),
    include_package_data=True,
    license_files=["LICENSE"],
    classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
    ],
)
